==> minitube_0.9.orig.tar.gz: minitube/locale/it_IT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT" sourcelanguage="en_US">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>C&apos;è vita fuori del browser!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versione %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation>Questa è una versione Beta, non aspettarti che sia perfetta.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Segnala problemi e manda le tue idee a %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 è Software Libero ma il suo sviluppo richiede tempo prezioso.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Per favore &lt;a href=&apos;%1&apos;&gt;fai una donazione con PayPal&lt;/a&gt; per aiutare lo sviluppo di %2.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Icona disegnata da %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Modalità compatta sviluppata da %1</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Tradotto da %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Rilasciato sotto licenza &lt;a href=&quot;%1&quot;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Quello che hai sempre voluto sapere su %1 e non hai mai osato chiedere</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>Supporto per i proxy HTTP svilupparo da %1</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation type="obsolete">Versione per Windows compilata da %</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Cancella</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Ricerca...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Mostra altri %1</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Nessun video</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Nessun altro video</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Indietro</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Vai alla vista precedente</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Ferma</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Ferma il video e torna alla ricerca</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Salta</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Salta al prossimo video</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Metti in pausa</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Schermo intero</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Vai in modalità schermo intero</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>Modalità compatta</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Nascondi la playlist e la barra degli strumenti</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation></translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation>Apri la pagina del video su YouTube</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Elimina i video selezionati dalla playlist</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Sposta &amp;sopra</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Sposta video selezionati verso l&apos;alto</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Sposta so&amp;tto</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Sposta i video selezionati verso il basso</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Ciao</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Sito &amp;web</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volume al %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Audio disattivato</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Audio attivato</translation>
    </message>
    <message>
        <source>Minitube on the Web</source>
        <translation type="obsolete">Minitube sul Web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 sul Web</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation>Fai una &amp;donazione con PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Supporta lo sviluppo di %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Informazioni</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informazioni su %1</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation type="obsolete">&amp;Ricerca</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Applicazione</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Apertura di %1</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Errore fatale: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Errore: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation></translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Continua</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>&amp;Esci dallo schermo intero</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Disattiva l&apos;audio</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Premi %1 per alzare il volume, %2 per abbassarlo</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Tempo rimanente: %1</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation>Il video ad alta definizione è abilitato</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation>Il video ad alta definizione è disabilitato</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation>Il video corrente è in alta definizione</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation>Il video corrente non è in alta definizione</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation>&amp;Cancella le ultime ricerche</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Più rilevanti</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Più recenti</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Più visti</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Stai guardando &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Errore di rete: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 visualizzazioni</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Benvenuto su &lt;a href=&quot;%1&quot;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Scrivi una parola chiave per iniziare a guardare i video.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Guarda</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Ultime ricerche</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>È disponibile una nuova versione di %1. &lt;a href=&apos;%2&apos;&gt;Aggiorna alla versione %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Mettiti comodo</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <source>&amp;Video options</source>
        <translation type="obsolete">Opzioni &amp;video</translation>
    </message>
    <message>
        <source>Use high quality video when available</source>
        <translation type="obsolete">Usa video ad alta definizione se disponibile</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">&amp;Chiudi</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Errore di rete: %1 per %2</translation>
    </message>
</context>
</TS>

==> minitube-1.1.tar.gz: minitube/locale/it_IT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT" sourcelanguage="en_US">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>C&apos;è vita fuori del browser!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versione %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation type="obsolete">Questa è una versione Beta, non aspettarti che sia perfetta.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Segnala problemi e manda le tue idee a %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 è Software Libero ma il suo sviluppo richiede tempo prezioso.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation type="obsolete">Per favore &lt;a href=&apos;%1&apos;&gt;fai una donazione con PayPal&lt;/a&gt; per aiutare lo sviluppo di %2.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Icona disegnata da %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Modalità compatta sviluppata da %1</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Tradotto da %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Rilasciato sotto licenza &lt;a href=&quot;%1&quot;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Quello che hai sempre voluto sapere su %1 e non hai mai osato chiedere</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>Supporto per i proxy HTTP svilupparo da %1</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation type="obsolete">Versione per Windows compilata da %</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>&lt;a href=&quot;%1&quot;&gt;Fai una donazione&lt;/a&gt; per aiutare lo sviluppo di %2.</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Cancella</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Ricerca...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Mostra altri %1</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Nessun video</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Nessun altro video</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation type="obsolete">&amp;Indietro</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation type="obsolete">Vai alla vista precedente</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Ferma</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Ferma il video e torna alla ricerca</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Salta</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Salta al prossimo video</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Metti in pausa</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Schermo intero</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Vai in modalità schermo intero</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>Modalità compatta</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Nascondi la playlist e la barra degli strumenti</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation type="obsolete">Apri la pagina del video su YouTube</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Elimina i video selezionati dalla playlist</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Sposta &amp;sopra</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Sposta video selezionati verso l&apos;alto</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Sposta so&amp;tto</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Sposta i video selezionati verso il basso</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Ciao</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Sito &amp;web</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volume al %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Audio disattivato</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Audio attivato</translation>
    </message>
    <message>
        <source>Minitube on the Web</source>
        <translation type="obsolete">Minitube sul Web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 sul Web</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation type="obsolete">Fai una &amp;donazione con PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Supporta lo sviluppo di %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Informazioni</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informazioni su %1</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation type="obsolete">&amp;Ricerca</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Applicazione</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Apertura di %1</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Errore fatale: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Errore: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation></translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Continua</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>&amp;Esci dallo schermo intero</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Disattiva l&apos;audio</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Premi %1 per alzare il volume, %2 per abbassarlo</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Tempo rimanente: %1</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation type="obsolete">Il video ad alta definizione è abilitato</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation type="obsolete">Il video ad alta definizione è disabilitato</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation type="obsolete">Il video corrente è in alta definizione</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation type="obsolete">Il video corrente non è in alta definizione</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation>&amp;Cancella le ultime ricerche</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>&amp;Cancella le ultime ricerche. L&apos;azione non potrà essere annullata.</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>La tua privacy è al sicuro</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube page</source>
        <translation>Apri su &amp;YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Vai su YouTube e metti in pausa</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;link</source>
        <translation>Copia il &amp;link a YouTube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Copia negli appunti il link a YouTube per il video corrente</translation>
    </message>
    <message>
        <source>Copy the video stream &amp;URL</source>
        <translation>Copia la &amp;URL dello stream video</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Copia negli appunti la URL dello stream per il video corrente</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Fai una donazione</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>La definizione video massima è impostata a %1</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Più rilevanti</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Più recenti</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Più visti</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Stai guardando &quot;%1&quot;</translation>
    </message>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Ora puoi incollare il link a YouTube in un&apos;altra applicazione</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Ora puoi incollare la URL dello stream in un&apos;altra applicazione</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Il link rimarrà valido per un periodo di tempo limitato.</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Questa è solo la versione demo di %1.</translation>
    </message>
    <message>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation>Ti permette di testare l&apos;applicazione e verificare che funzioni sul tuo computer.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continua</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Compra la versione completa</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Errore di rete: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 visualizzazioni</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Benvenuto su &lt;a href=&quot;%1&quot;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Scrivi una parola chiave per iniziare a guardare i video.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Guarda</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Ultime ricerche</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>È disponibile una nuova versione di %1. &lt;a href=&apos;%2&apos;&gt;Aggiorna alla versione %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Mettiti comodo</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">Opzioni</translation>
    </message>
    <message>
        <source>&amp;Video options</source>
        <translation type="obsolete">Opzioni &amp;video</translation>
    </message>
    <message>
        <source>Use high quality video when available</source>
        <translation type="obsolete">Usa video ad alta definizione se disponibile</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">&amp;Chiudi</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Errore di rete: %1 per %2</translation>
    </message>
</context>
</TS>
